| GUI | R Documentation |
This function is a wrapper around gazepath and provides a graphical user interface (GUI) in shiny to parse raw eye-tracking data into fixations and saccades. The GUI functions opens a browser that serves as GUI to parse and visualize eye-tracking data
GUI()
no arguments
no details
nothing is returned
Daan van Renswoude & Ingmar Visser
van Renswoude, D. R., Raijmakers, M. E. J., Koornneef, A., Johnson, S. P., Hunnius, S. and Visser, I. (2018). Gazepath: An eye-tracking analysis tool that accounts for individual differences and data quality. Behavior Research Methods, 50(2), 834-852. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13428-017-0909-3")}
Mould, M. S., Foster, D. H., Amano, K. and Oakley, J. P. (2012). A simple nonparametric method for classifying eye fixations. Vision Research, 57, 18-25.
## Not run:
GUI()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.