| gazepath-package | R Documentation |
Eye-tracking data must be transformed into fixations and saccades before it can be analyzed. This package provides a non-parametric speed-based approach to do this on a trial basis. The method is especially useful when there are large differences in data quality, as the thresholds are adjusted accordingly. The same pre-processing procedure can be applied to all participants, while accounting for individual differences in data quality.
| Package: | gazepath |
| Type: | Package |
| Version: | 1.4 |
| Date: | 2026-05-28 |
| License: | GPL-2 |
Ingmar Visser & Daan van Renswoude
Maintainer: Ingmar Visser <i.visser@uva.nl>
van Renswoude, D. R., Raijmakers, M. E. J., Koornneef, A., Johnson, S. P., Hunnius, S. and Visser, I. (2018). Gazepath: An eye-tracking analysis tool that accounts for individual differences and data quality. Behavior Research Methods, 50(2), 834-852. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13428-017-0909-3")}
Mould, M. S., Foster, D. H., Amano, K. and Oakley, J. P. (2012). A simple nonparametric method for classifying eye fixations. Vision Research, 57, 18-25.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.